"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = loadData;
exports.getData = getData;
exports.load = load;

require("core-js/modules/es7.array.includes");

require("core-js/modules/es6.string.includes");

require("core-js/modules/es6.regexp.replace");

var _path = _interopRequireDefault(require("path"));

function loadData(contentPath, options) {
  if (options === void 0) {
    options = {};
  }

  return JSON.parse(getData(contentPath, options));
}

function getData(contentPath, options) {
  // find all import occurrences and replace with the actual content
  return load(contentPath, options).replace(/"import!(.*?)"/gi, function (_, group) {
    return (// recursion is supported
      getData(_path.default.resolve(__dirname, _path.default.dirname(contentPath), group), options)
    );
  });
}

function load(contentPath, options) {
  var extension = _path.default.extname(contentPath).slice(1); // use normal require


  if (['json', 'js'].includes(extension)) {
    var result = require(contentPath); // if js export was a function, execute it and use the result


    if (typeof result === 'function') {
      result = result();
    }

    if (typeof result === 'string') {
      return result;
    } // convert object to json string


    return JSON.stringify(result);
  } // resolve using provided mapper


  if (options.resolvers && options.resolvers[extension]) {
    var _result = options.resolvers[extension](contentPath);

    if (typeof _result === 'string') {
      return _result;
    } // convert object to json string


    return JSON.stringify(_result);
  }

  throw new Error("Extension \"" + extension + "\" for path \"" + contentPath + "\" is not supported, please configure a resolve function by setting \"options.resolvers." + extension + "\". It will receive a path and should return the content as a string.");
}